# Section Links With Weird HTML

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Section links are awesome.

## 1. Section dfn

§ 2 Section B

§ 2 Section B

## 2. Section B

§ 1 Section dfn

§ 1 Section dfn

## 3. Longer titles look nicer like this

§ 3 Longer titles look nicer like this

§ 3 Longer titles look nicer like this

Inside a sentence, § 3 Longer titles look nicer like this looks like this.

## Index

### Terms defined by this specification

- dfn, in §1